[![Build Status](https://travis-ci.org/gflorio/geortree.svg?branch=master)](https://travis-ci.org/gflorio/geortree)
[![Coverage Status](https://coveralls.io/repos/github/GFlorio/geortree/badge.svg?branch=master)](https://coveralls.io/github/GFlorio/geortree?branch=master)
[![PyPI version](https://badge.fury.io/py/geortree.svg)](https://badge.fury.io/py/geortree)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/geortree.svg)](https://pypi.python.org/pypi/geortree/)

# GeoRTree

Reasonably efficient R-Tree implementation, adapted to work with geographic coordinates.
